@@ -5,17 +5,17 @@
 modname = 'cubicweb_s3storage'
 distname = 'cubicweb-s3storage'
 
-numversion = (3, 0, 0)
+numversion = (3, 1, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 description = 'A Cubicweb Storage that stores the data on S3'
-web = 'http://www.cubicweb.org/project/%s' % distname
+web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.24.7',
+    'cubicweb': ">= 3.24.7, < 3.36.0",
     'six': '>= 1.4.0',
     'boto3': None,
 }
